module Fastlane
  module Actions
    class ImportProvisioningAction < Action
      def self.run(config)
        Fastlane::Polidea.session.action_launched("import_provisioning", config)

        path = config[:path]
        profiles = Dir.glob File.join(path, "*.mobileprovision")

        # Install the provisioning profiles
        profiles.each do |profile|
          FastlaneCore::ProvisioningProfile.install(profile)
        end
        UI.success "Successfully imported:\n#{profiles.join("\n")}"

        Fastlane::Polidea.session.action_completed("import_provisioning")

        true
      end

      def self.available_options
        [
          FastlaneCore::ConfigItem.new(key: :path,
                                       env_name: "",
                                       description: "Directory containing provisioning profiles",
                                       default_value: "signing")
        ]
      end

      def self.description
        "Import provisioning profiles from directory (`signing` is default)"
      end

      def self.author
        "Piotrek Dubiel"
      end

      def self.is_supported?(platform)
        platform == :ios
      end
    end
  end
end
