module Fastlane
  module Actions
    module SharedValues
      RELEASE_NOTES = :RELEASE_NOTES
    end

    class ReleaseNotesAction < Action
      def self.run(config)
        Fastlane::Polidea.session.action_launched("release_notes", config)

        current_tag = sh "git describe --exact-match --tags HEAD"
        tag_info = sh "git cat-file -p #{current_tag}"
        release_notes = tag_info.split("\n").drop(5).join("\n")
        UI.success "Extracted release notes:\n#{release_notes}"
        Actions.lane_context[SharedValues::RELEASE_NOTES] = release_notes
        ENV[SharedValues::RELEASE_NOTES.to_s] = release_notes

        Fastlane::Polidea.session.action_completed("release_notes")

        release_notes
      end

      def self.description
        "Extracts release notes from git tag message"
      end

      def self.output
        [
          ['RELEASE_NOTES', 'Release notes extracted from git tag']
        ]
      end

      def self.author
        "Piotrek Dubiel"
      end

      def self.is_supported?(platform)
        true
      end
    end
  end
end
