require 'faraday'
require 'json'

module Fastlane
  module Shuttle
    class Client
      def initialize(base_url, access_token)
        retry_options = {
          max: 2,
          interval: 0.05,
          interval_randomness: 0.5,
          backoff_factor: 2
        }

        @conn = Faraday.new(
          url: base_url,
          headers: {
            'Content-Type' => 'application/json',
            'Access-Token' => access_token
          }
        ) do |conn|
          conn.request :retry, retry_options
          conn.request :multipart
          conn.response :raise_error
          conn.response :json
          conn.adapter :net_http
        end
      end

      def create_build(platform, app_identifier, build)
        @conn.post(
          "cd/apps/#{platform}/#{app_identifier}/builds/v2",
          { build: build }.to_json
        )
      end

      def get_upload_urls(platform, app_id, build_identifier)
        response = @conn.get(
          "projects/apps/#{platform}/#{app_id}/builds/#{build_identifier}/upload-url/v2"
        )
        return response.body
      end
    end
  end
end
